<div class="ctsurn">
	<a href="http://data.perseus.org/catalog/{{urn["work"]}}" target='_blank'>Catalog Record</a> - 
	<a href="http://www.perseids.org/apps/treebank?text_uri=http://perseids.org/cts5/nemo/citations/{{urn}}" target='_blank'>Create Treebank</a> <br />
	<a href="/api/cts?request=GetPassage&urn={{urn}}" target='_blank'>{{urn}}</a>
</div>
