<div class="logo-container">
    <a href="{{ url_for('.r_index') }}"><img class="logo" src="{{url_for('.secondary_assets', filetype='static', asset='rev_running_man.png')}} " alt="Capitains Nemo" /></a>
</div>
<header>
    <span class="content">Collection</span>
</header>
<ul class="menu">
    {% for collection in collections %}
        <li><a class="{{collection|active_link(url)}}" href="{{url_for('.r_collection', collection=collection)}}">{{collection|collection_i18n(lang)}}</a></li>
    {% endfor %}
</ul>
{% if textgroups %}
<header>
    <span class="content">Authors</span>
</header>
<ul class="menu">
    {% for textgroup in textgroups %}
        <li><a class="{{textgroup.urn.textgroup|active_link(url)}}" href="{{url_for('.r_texts', collection=textgroup.urn.namespace, textgroup=textgroup.urn.textgroup)}}">{{textgroup.metadata['groupname'][lang]}}</a></li>
    {% endfor %}
</ul>
{% endif %}